//package ???;

import java.awt.*;
import java.awt.event.*;
import java.lang.reflect.Constructor;

import javax.swing.*;

/**
 * Demo JTextField.
 * 
 * @author Heiner K&uuml;cker
 */
public class JTextFieldsDemo extends JFrame
{

    JTextField onlyDigitsTextField;
    JTextField onlyHexDigitsTextField;
    JTextField upperCaseTextField;

    public JTextFieldsDemo()
    {
        super("JTextFieldsDemo");

        //static Reference to ContentPane for error messages
        cp = this.getContentPane();

        //entirely Frame
        Container cp = getContentPane();

        //Form
        JPanel formPanel = new JPanel();
        cp.add(formPanel);

        GridLayout formLayout = new GridLayout();
        formLayout.setRows(2);
        formPanel.setLayout(formLayout);

        //Form oben
        JPanel formTopPanel = new JPanel();
        formPanel.add(formTopPanel);

        onlyDigitsTextField =
            addTextfield(
                formTopPanel,
                "JOnlyDigitsTextField",
                10,
                JOnlyDigitsTextField.class);

        onlyHexDigitsTextField =
            addTextfield(
                formTopPanel,
                "JOnlyHexDigitsTextField",
                10,
                JOnlyHexDigitsTextField.class);

        upperCaseTextField =
            addTextfield(
                formTopPanel,
                "JUpperCaseTextField",
                10,
                JUpperCaseTextField.class);

        //Form unten
        JPanel formBottPanel = new JPanel();
        formPanel.add(formBottPanel);

        JLabel label1 = new JLabel();
        label1.setText(
            "Try rigtht mouse button and Ctrl-C, Ctrl-X and Ctrl-V in TextField");
        formBottPanel.add(label1);

        JLabel label2 = new JLabel();
        label2.setText(
            "Probieren Sie bitte den rechten Mausknopf und Strg-C, Strg-X and Strg-V im Textfeld");
        formBottPanel.add(label2);

        setVisible(true);
    }

    /**
     * Erzeugen Textfeld mit LabelText ber Texteingabefeld.
     * 
     * @param pLabelStr
     * @return
     */
    private JTextField addTextfield(
        final Container pCont,
        final String pLabelStr,
        final int pSize,
        final Class pJTextfieldClass)
    {
        final JPanel fieldPanel = new JPanel();
        final GridLayout fieldLayout = new GridLayout();
        fieldLayout.setRows(2);
        fieldPanel.setLayout(fieldLayout);

        final JLabel label = new JLabel(pLabelStr);
        fieldPanel.add(label);

        final JTextField textField;
        try
        {
            final Constructor constructor =
                pJTextfieldClass.getConstructor(new Class[] { int.class });
            textField =
                (JTextField) constructor.newInstance(
                    new Object[] { new Integer(pSize)});
        }
        catch (Exception e)
        {
            throw new RuntimeException(e.getMessage());
        }

        fieldPanel.add(textField);

        pCont.add(fieldPanel);
        return textField;
    }

    /**
     * Start Demo.
     * 
     * @param args
     */
    public static void main(String[] args)
    {

        try
        {
            UIManager.setLookAndFeel(
                "com.sun.java.swing.plaf.windows.WindowsLookAndFeel");
        }
        catch (Exception e)
        {
            System.err.println("unknown Look & Feel: " + e.getMessage());
        }

        JFrame frame = new JTextFieldsDemo();

        WindowListener listener = new WindowAdapter()
        {
            public void windowClosing(WindowEvent we)
            {
                System.exit(0);
            }
        };

        frame.addWindowListener(listener);
        frame.setSize(500, 200);
        frame.setResizable(false);
        frame.setVisible(true);
    }

    /**
     * statischer Halter der ContentPane fr die Fehlermeldungen
     */
    static Container cp;

    /**
     * show error message.
     * 
     * @param pMsgStr
     */
    public static void showErrMsg(final String pMsgStr)
    {
        JOptionPane.showMessageDialog(
            cp,
            pMsgStr,
            "Error",
            JOptionPane.ERROR_MESSAGE);
    }

    /**
     * Ja-Nein-Abfrage.
     * 
     * @param pQuestionStr
     * @return true, wenn Antwort 'Ja'
     */
    public static boolean showYesNoMsg(final String pQuestionStr)
    {
        final int questResult =
            JOptionPane.showConfirmDialog(
                cp,
                pQuestionStr + " ?",
                "Question",
                JOptionPane.YES_NO_OPTION);
        return questResult == 0;
    }
}
